==> blueocean-events-1.0.0-b14-sources.jar: io/jenkins/blueocean/events/PipelineEventChannel.java <==
/*
 * The MIT License
 *
 * Copyright (c) 2016, CloudBees, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package io.jenkins.blueocean.events;

/**
 * @author <a href="mailto:tom.fennelly@gmail.com">tom.fennelly@gmail.com</a>
 */
public interface PipelineEventChannel {

    String NAME = "pipeline";

    /**
     * The event names.
     * @see org.jenkins.pubsub.EventProps.Jenkins#jenkins_event
     */
    enum Event {
        pipeline_start,
        pipeline_end,
        pipeline_block_start,
        pipeline_block_end,
        pipeline_step,
        pipeline_stage,
    }

    /**
     * Event property names.
     */
    enum EventProps {
        pipeline_job_name,
        pipeline_run_id,
        pipeline_context,
        pipeline_step_name,
        pipeline_step_flownode_id,
        pipeline_step_stage_name,
        pipeline_step_stage_id,
    }
}

==> blueocean-events-1.27.23-sources.jar: io/jenkins/blueocean/events/PipelineEventChannel.java <==
/*
 * The MIT License
 *
 * Copyright (c) 2016, CloudBees, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package io.jenkins.blueocean.events;

/**
 * @author <a href="mailto:tom.fennelly@gmail.com">tom.fennelly@gmail.com</a>
 */
public interface PipelineEventChannel {

    String NAME = "pipeline";

    /**
     * The event names.
     * @see org.jenkinsci.plugins.pubsub.EventProps.Jenkins#jenkins_event
     */
    enum Event {
        pipeline_start,
        pipeline_end,
        pipeline_block_start,
        pipeline_block_end,
        pipeline_step,
        pipeline_stage,
    }

    /**
     * Event property names.
     */
    enum EventProps {
        pipeline_job_name,
        pipeline_run_id,
        pipeline_context,
        pipeline_step_name,
        pipeline_step_flownode_id,
        pipeline_step_stage_name,
        pipeline_step_stage_id,
        pipeline_step_is_paused,
    }
}
